Graphical User Interface for the psyplot package
================================================

.. start-badges

.. list-table::
    :stub-columns: 1
    :widths: 10 90

    * - docs
      - |docs|
    * - tests
      - |circleci| |appveyor| |codecov|
    * - package
      - |version| |conda| |github| |zenodo|
    * - implementations
      - |supported-versions| |supported-implementations|

.. |docs| image:: https://img.shields.io/github/deployments/psyplot/psyplot-gui/github-pages
    :alt: Documentation
    :target: http://psyplot.github.io/psyplot-gui/

.. |circleci| image:: https://circleci.com/gh/psyplot/psyplot-gui/tree/master.svg?style=svg
    :alt: CircleCI
    :target: https://circleci.com/gh/psyplot/psyplot-gui/tree/master

.. |appveyor| image:: https://ci.appveyor.com/api/projects/status/bud4ov6lddrjvt88/branch/master?svg=true
    :alt: AppVeyor
    :target: https://ci.appveyor.com/project/psyplot/psyplot-gui-q726s

.. |codecov| image:: https://codecov.io/gh/psyplot/psyplot-gui/branch/master/graph/badge.svg
    :alt: Coverage
    :target: https://codecov.io/gh/psyplot/psyplot-gui

.. |version| image:: https://img.shields.io/pypi/v/psyplot-gui.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/psyplot-gui

.. |conda| image:: https://anaconda.org/conda-forge/psyplot-gui/badges/version.svg
    :alt: conda
    :target: https://anaconda.org/conda-forge/psyplot-gui

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/psyplot-gui.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/psyplot-gui

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/psyplot-gui.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/psyplot-gui

.. |zenodo| image:: https://zenodo.org/badge/55793611.svg
    :alt: Zenodo
    :target: https://zenodo.org/badge/latestdoi/55793611

.. |github| image:: https://img.shields.io/github/release/psyplot/psyplot-gui.svg
    :target: https://github.com/psyplot/psyplot-gui/releases/latest
    :alt: Latest github release


.. end-badges

Welcome! This package enhances the interactive visualization framework
psyplot_ with a graphical user interface using PyQt_. See the homepage of the
main project on examples on the possibilities with psyplot_.

You can see the full documentation under
`psyplot.github.io/psyplot-gui/ <http://psyplot.github.io/psyplot-gui>`__

.. _PyQt: https://riverbankcomputing.com/software/pyqt/intro
.. _psyplot: http://psyplot.github.io/


Copyright
---------
Copyright © 2021 Helmholtz-Zentrum Hereon, 2020-2021 Helmholtz-Zentrum
Geesthacht, 2016-2021 University of Lausanne

psyplot-gui is released under the GNU LGPL-3.O license.
See COPYING and COPYING.LESSER in the root of the repository for full
licensing details.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Lesser General Public License version 3.0 as
published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU LGPL-3.0 license for more details.

You should have received a copy of the GNU LGPL-3.0 license
along with this program.  If not, see https://www.gnu.org/licenses/.
